@@ -2,14 +2,15 @@
 
 package HPC::Runner::GnuParallel;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use DateTime;
 use DateTime::Format::Duration;
 
 use Moose;
-extends 'HPC::Runner';
-extends 'HPC::Runner::MCE';
+#extends 'HPC::Runner';
+#extends 'HPC::Runner::MCE';
+extends qw(HPC::Runner HPC::Runner::MCE);
 
 #with 'MooseX::Getopt';
 with 'MooseX::Getopt::Usage';
@@ -98,8 +99,8 @@ sub go{
 
     $self->logname('gnuparallel');
 
-#    $self->prepend_logfile("MAIN_");
-#    $self->log($self->init_log);
+    $self->prepend_logfile("MAIN_");
+    $self->log($self->init_log);
 
     $self->parse_file_gnuparallel;
 
@@ -111,7 +112,7 @@ sub go{
         pattern => '%Y years, %m months, %e days, %H hours, %M minutes, %S seconds'
     );
 
-#    $self->log->info("Total execution time ".$format->format_duration($duration));
+    $self->log->info("Total execution time ".$format->format_duration($duration));
     return;
 }
 
